# Updated 2021 December 15

#### CODE PREAMBLE AND DESCRIPTION ####

## Code preamble: prepare workspace and load R packages

rm(list = ls())     # Clear workspace
library(data.table) # R package for using data.tables as augmented data.frames
library(zoo)        # R package that has some date indexing functions etc.
library(RANN)       # R package that does nearest neighbor spatial joining
datadir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/data" # SET THIS: top-level data directory
setwd(datadir)
maxdate.panel = "2021-07-18"

## Data and programming notes:
#
# 1. Running this code requires fairly little computer RAM, less than 1 GB.
#
# 2. Vaccination data from the CDC are available starting on February 19, 2021.
#    Although other states' data begins on Feb. 13, Texas begins six days later on Feb. 19.
#    This code subsets the vaccination data to start with February 19, 2021.
#
#    COVID-19 cases data and the overall panel starts with the earliest available data on January 22, 2020.
#
#    COVID-19 (intensive care unit) hospitalizations data starts on July 15, 2020
#    There are few populated values on earlier dates, but it's very sparse and somewhat erroneous.
# 
# 3. The CDC vaccination data are known to have errors, including dates assigned to some vaccinations,
#    e.g. some vaccinations from two consecutive days might be assigned to the same date.
#    This code corrects about 2.7 percent of observations by smoothing vaccination data within
#    the week containing each outlier---defined based on the day of week and the 7-day moving average.
# 

## Data sources:
#
# [A] Downloaded automatically
#
#   1) State COVID-19 vaccination data by date from the Centers for Disease Control and Prevention (CDC) at
#      https://covid.cdc.gov/covid-data-tracker
#      https://data.cdc.gov/Vaccinations/COVID-19-Vaccinations-in-the-United-States-Jurisdi/unsk-b7fc
#
#   2) State COVID-19 cases and deaths by date from the Centers for Disease Control and Prevention (CDC) at
#      https://www.cdc.gov/coronavirus/2019-ncov/cases-updates/cases-in-us.html
#
#   3) State COVID-19 hospitalizations by date from the Department of Health & Human Services at
#      https://healthdata.gov/Hospital/COVID-19-Reported-Patient-Impact-and-Hospital-Capa/g62h-syeh
#
#   4) State population and population density for 2020 from the Census Bureau at
#      https://www.census.gov/data/tables/time-series/dec/density-data-text.html
#
#   5) Census Block Group centers of population from the Census Bureau at
#      https://www.census.gov/geographies/reference-files/time-series/geo/centers-population.html
#
#   6) State Gross Domestic Product for 2020 from the Bureau of Economic Analysis at
#      https://apps.bea.gov/regional/downloadzip.cfm
#
#   7) State presidential elections results for 2020 from Tony McGovern at
#      https://github.com/tonmcg/US_County_Level_Election_Results_08-20
#
#   8) State community mobility indexes by date from Google Community Mobility Reports at 
#      https://www.google.com/covid19/mobility/
#
#   9) State names to abbreviations and FIPS codes crosswalk from Danton Noriega at
#      https://gist.github.com/dantonnoriega/bf1acd2290e15b91e6710b6fd3be0a53
#
# [B] Downloaded manually
#
#  10) State influenza vaccination rates for 2019 from the Centers for Medicare and Medicaid Services at
#      https://data.cms.gov/mapping-medicare-disparities
#
#  11) All COVID-19 vaccination site locations from www.vaccinatethestates.com
#

#### (DOWN)LOAD THE DATA COMPONENTS THAT CAN BE DOWNLOADED AUTOMATICALLY ####

setwd(file.path(datadir, "downloaded_automatically"))

# 1) State COVID-19 vaccinations data by date 

if(!file.exists("covid-vaccinations-states.csv")) {
  download.file("https://data.cdc.gov/api/views/unsk-b7fc/rows.csv?accessType=DOWNLOAD", "covid-vaccinations-states.csv")}
vaccinations <- fread("covid-vaccinations-states.csv")
setnames(vaccinations, "Date", "date")
vaccinations[, date := as.Date(date, format = "%m/%d/%Y")]
vaccinations <- vaccinations[date <= maxdate.panel]

# 2) State COVID-19 cases and deaths by date

if(!file.exists("covid-cases-deaths-states.csv")) {
  download.file("https://data.cdc.gov/api/views/9mfq-cb36/rows.csv?accessType=DOWNLOAD", "covid-cases-deaths-states.csv")}
covid <- fread("covid-cases-deaths-states.csv")
covid[, date := as.Date(submission_date, format = "%m/%d/%Y")]
covid <- covid[date <= maxdate.panel]

# 3) State COVID-19 hospitalizations by date

if(!file.exists("covid-hospitalizations-states.csv")) {
  download.file("https://healthdata.gov/api/views/g62h-syeh/rows.csv?accessType=DOWNLOAD", "covid-hospitalizations-states.csv")}
hospitalizations <- fread("covid-hospitalizations-states.csv")
hospitalizations[, date := as.Date(date, format = "%Y/%m/%d")]
hospitalizations <- hospitalizations[date <= maxdate.panel]

# 4) State population and population density

if(!file.exists("population-density-states.csv")) {
  download.file("https://www2.census.gov/programs-surveys/decennial/2020/data/apportionment/apportionment.csv", "population-density-states.csv")}
popdensity <- fread("population-density-states.csv")[`Geography Type` == "State" & Year == 2020 & Name != "Puerto Rico"]

# 5) Census Block Group centers of population

if(!file.exists("population-centers-census-blocks.csv")) {
  download.file("https://www2.census.gov/geo/docs/reference/cenpop2010/blkgrp/CenPop2010_Mean_BG.txt",
                "population-centers-census-blocks.csv")}
cbgpopcen <- fread("population-centers-census-blocks.csv")[as.numeric(STATEFP) <= 56]

# 6) State Gross Domestic Product for 2020

if(!file.exists("SAGDP-states.zip")) {
  download.file("https://apps.bea.gov/regional/zip/SAGDP.zip", "SAGDP-states.zip")}
unzip("SAGDP-states.zip", files = c("SAGDP1__ALL_AREAS_1997_2020.csv"))
gdp <- fread("SAGDP1__ALL_AREAS_1997_2020.csv", fill = TRUE)[LineCode == 3][as.integer(GeoFIPS) %in% 1000:56000]
unlink("SAGDP1__ALL_AREAS_1997_2020.csv")

# 7) State presidential elections results for 2020

if(!file.exists("presidential-elections-states-counties.csv")) {
  download.file("https://raw.githubusercontent.com/tonmcg/US_County_Level_Election_Results_08-20/master/2020_US_County_Level_Presidential_Results.csv",
                "presidential-elections-states-counties.csv")}
elections <- fread("presidential-elections-states-counties.csv")[, lapply(.SD, sum), by = state_name, .SDcols = c("votes_gop", "votes_dem", "total_votes")]

# 8) State community mobility indexes by date

if(!file.exists("Region_Mobility_Report_CSVs.zip")) {
  download.file("https://www.gstatic.com/covid19/mobility/Region_Mobility_Report_CSVs.zip", "Region_Mobility_Report_CSVs.zip")}
unzip("Region_Mobility_Report_CSVs.zip", files = c("2021_US_Region_Mobility_Report.csv", "2020_US_Region_Mobility_Report.csv"))
mobility <- rbind(fread("2020_US_Region_Mobility_Report.csv")[sub_region_1 != "" & sub_region_2 == ""],
                  fread("2021_US_Region_Mobility_Report.csv")[sub_region_1 != "" & sub_region_2 == ""])
unlink(c("2021_US_Region_Mobility_Report.csv", "2020_US_Region_Mobility_Report.csv"))
mobility <- mobility[date <= maxdate.panel]

# 9) State name to abbreviation and FIPS crosswalk

if(!file.exists("crosswalk-names-abbreviations-fips-states.csv")) {
  download.file(paste0("https://gist.githubusercontent.com/dantonnoriega/bf1acd2290e15b91e6710b6fd3be0a53/raw/",
                       "11d15233327c8080c9646c7e1f23052659db251d/us-state-ansi-fips.csv"), "crosswalk-names-abbreviations-fips-states.csv")}
state2fips <- fread("crosswalk-names-abbreviations-fips-states.csv")

#### LOAD THE DATA COMPONENTS THAT MUST BE DOWNLOADED MANUALLY ####

setwd(file.path(datadir, "downloaded_manually"))

# *** NOTE: these below data must be downloaded manually and are loaded but not downloaded by this code ***

# 10) All COVID-19 vaccination site locations

vaccinesites <- fread("vaccine_sites.csv")

# 11) State influenza vaccination rates for 2019 [data must be manually downloaded]

influenza <- fread("mmd_data.csv")[fips <= 56]

#### SMOOTH VACCINATION DATA FOR OUTLIER ERRORS (SEE CODE DESCRIPTION) ####

setkey(vaccinations, Location, date)
vaccinations <- merge(vaccinations, state2fips[, .(stusps)], by.x = "Location", by.y = "stusps")
vaccinations[, week_of_sample := floor(as.numeric(difftime(date, "2021-05-12", units = "days")) / 7) + 1]
vaccinations[, weekdate := min(date), by = week_of_sample]

# Define a state-specific day-of-week weight

vaccinations[, daily_administered := Administered - shift(Administered)]
vaccinations[Location != shift(Location) | date <= "2021-02-13", daily_administered := NA]
vaccinations[, total_administered := sum(daily_administered, na.rm = TRUE), by = Location]
vaccinations[, dow_weight := sum(daily_administered, na.rm = TRUE) / total_administered, by = .(Location, wday(date))]
vaccinations[, cumul_dow_weight_weekdate :=  cumsum(dow_weight), by = .(Location, weekdate)]

# First, tag the outliers using criterion of:
#  daily vaccinations volume greater than twice the value of the 7-day moving average, adjusted for day of the week
# Note: not tagging data as "outliers" in the first week of data (Feb. 19 - Feb. 24)

vaccinations[, ma7_daily_administered := frollmean(daily_administered, n = 7, align = "center")]
vaccinations[daily_administered / ma7_daily_administered > 2 * dow_weight * 7, outlier_tag := 1]
vaccinations[date <= "2021-02-24", outlier_tag := NA]

length(vaccinations[date <= "2021-06-20" & outlier_tag == 1]$outlier_tag)
length(vaccinations[date <= "2021-06-20"]$Administered)
length(vaccinations[date <= "2021-06-20" & outlier_tag == 1]$outlier_tag) / length(vaccinations[date <= "2021-06-20"]$Administered)

# Next, tag the outlier weeks as any week that contains an outlier day

suppressWarnings(vaccinations[, outlier_week := max(outlier_tag, na.rm = TRUE), by = .(Location, weekdate)])
vaccinations[outlier_week == 1, dayct_outlier_week := .N, by = .(Location, weekdate)]
vaccinations[dayct_outlier_week != 7 | outlier_week == -Inf, outlier_week := NA]

# Finally, for selected outcome variables (used in the study), replace all values in the week-of-sample that contains the outlier
# Replace these data by reallocating the total change across the week using state-specific day-of-week weights
# This preserves the cumulative change for each week and only reallocates that change across days within the outlier week

# Vaccination total dose 1 administered: includes all manufacturers

vaccinations[, Administered_Dose1_Recip := as.numeric(Administered_Dose1_Recip)]
vaccinations[Location == shift(Location, n = 1, type = "lag"), 
             weekstart_Administered_Dose1_Recip := shift(Administered_Dose1_Recip, n = 1, type = "lag")]
vaccinations[weekdate == shift(weekdate, n = 1, type = "lag") | is.na(outlier_week), weekstart_Administered_Dose1_Recip := NA]
vaccinations[outlier_week == 1, 
             weekstart_Administered_Dose1_Recip := max(weekstart_Administered_Dose1_Recip, na.rm = TRUE), by = .(Location, weekdate)]
vaccinations[outlier_week == 1, weeksend_Administered_Dose1_Recip := max(Administered_Dose1_Recip), by = .(Location, weekdate)]
vaccinations[outlier_week == 1 & weekstart_Administered_Dose1_Recip <= weeksend_Administered_Dose1_Recip, 
             Administered_Dose1_Recip := weekstart_Administered_Dose1_Recip +
               cumul_dow_weight_weekdate * (weeksend_Administered_Dose1_Recip - weekstart_Administered_Dose1_Recip)]

# Vaccination total Janssen administered

vaccinations[, Administered_Janssen := as.numeric(Administered_Janssen)]
vaccinations[Location == shift(Location, n = 1, type = "lag"), 
             weekstart_Administered_Janssen := shift(Administered_Janssen, n = 1, type = "lag")]
vaccinations[weekdate == shift(weekdate, n = 1, type = "lag") | is.na(outlier_week), weekstart_Administered_Janssen := NA]
vaccinations[outlier_week == 1, 
             weekstart_Administered_Janssen := max(weekstart_Administered_Janssen, na.rm = TRUE), by = .(Location, weekdate)]
vaccinations[outlier_week == 1, weeksend_Administered_Janssen := max(Administered_Janssen), by = .(Location, weekdate)]
vaccinations[outlier_week == 1 & weekstart_Administered_Janssen <= weeksend_Administered_Janssen, 
             Administered_Janssen := weekstart_Administered_Janssen + 
               cumul_dow_weight_weekdate * (weeksend_Administered_Janssen - weekstart_Administered_Janssen)]

# Vaccination total Moderna administered

vaccinations[, Administered_Moderna := as.numeric(Administered_Moderna)]
vaccinations[Location == shift(Location, n = 1, type = "lag"), 
             weekstart_Administered_Moderna := shift(Administered_Moderna, n = 1, type = "lag")]
vaccinations[weekdate == shift(weekdate, n = 1, type = "lag") | is.na(outlier_week), weekstart_Administered_Moderna := NA]
vaccinations[outlier_week == 1, 
             weekstart_Administered_Moderna := max(weekstart_Administered_Moderna, na.rm = TRUE), by = .(Location, weekdate)]
vaccinations[outlier_week == 1, weeksend_Administered_Moderna := max(Administered_Moderna), by = .(Location, weekdate)]
vaccinations[outlier_week == 1 & weekstart_Administered_Moderna <= weeksend_Administered_Moderna, 
             Administered_Moderna := weekstart_Administered_Moderna + 
               cumul_dow_weight_weekdate * (weeksend_Administered_Moderna - weekstart_Administered_Moderna)]

# Vaccination total Pfizer administered

vaccinations[, Administered_Pfizer := as.numeric(Administered_Pfizer)]
vaccinations[Location == shift(Location, n = 1, type = "lag"), 
             weekstart_Administered_Pfizer := shift(Administered_Pfizer, n = 1, type = "lag")]
vaccinations[weekdate == shift(weekdate, n = 1, type = "lag") | is.na(outlier_week), weekstart_Administered_Pfizer := NA]
vaccinations[outlier_week == 1, 
             weekstart_Administered_Pfizer := max(weekstart_Administered_Pfizer, na.rm = TRUE), by = .(Location, weekdate)]
vaccinations[outlier_week == 1, weeksend_Administered_Pfizer := max(Administered_Pfizer), by = .(Location, weekdate)]
vaccinations[outlier_week == 1 & weekstart_Administered_Pfizer <= weeksend_Administered_Pfizer, 
             Administered_Pfizer := weekstart_Administered_Pfizer + 
               cumul_dow_weight_weekdate * (weeksend_Administered_Pfizer - weekstart_Administered_Pfizer)]

# Vaccination total Moderna dose 2 administered

vaccinations[, Series_Complete_Moderna := as.numeric(Series_Complete_Moderna)]
vaccinations[Location == shift(Location, n = 1, type = "lag"), 
             weekstart_Series_Complete_Moderna := shift(Series_Complete_Moderna, n = 1, type = "lag")]
vaccinations[weekdate == shift(weekdate, n = 1, type = "lag") | is.na(outlier_week), weekstart_Series_Complete_Moderna := NA]
vaccinations[outlier_week == 1, 
             weekstart_Series_Complete_Moderna := max(weekstart_Series_Complete_Moderna, na.rm = TRUE), by = .(Location, weekdate)]
vaccinations[outlier_week == 1, weeksend_Series_Complete_Moderna := max(Series_Complete_Moderna), by = .(Location, weekdate)]
vaccinations[outlier_week == 1 & weekstart_Series_Complete_Moderna <= weeksend_Series_Complete_Moderna, 
             Series_Complete_Moderna := weekstart_Series_Complete_Moderna +
               cumul_dow_weight_weekdate * (weeksend_Series_Complete_Moderna - weekstart_Series_Complete_Moderna)]

# Vaccination total Pfizer dose 2 administered

vaccinations[, Series_Complete_Pfizer := as.numeric(Series_Complete_Pfizer)]
vaccinations[Location == shift(Location, n = 1, type = "lag"), 
             weekstart_Series_Complete_Pfizer := shift(Series_Complete_Pfizer, n = 1, type = "lag")]
vaccinations[weekdate == shift(weekdate, n = 1, type = "lag") | is.na(outlier_week), weekstart_Series_Complete_Pfizer := NA]
vaccinations[outlier_week == 1, 
             weekstart_Series_Complete_Pfizer := max(weekstart_Series_Complete_Pfizer, na.rm = TRUE), by = .(Location, weekdate)]
vaccinations[outlier_week == 1, weeksend_Series_Complete_Pfizer := max(Series_Complete_Pfizer), by = .(Location, weekdate)]
vaccinations[outlier_week == 1 & weekstart_Series_Complete_Pfizer <= weeksend_Series_Complete_Pfizer, 
             Series_Complete_Pfizer := weekstart_Series_Complete_Pfizer +
               cumul_dow_weight_weekdate * (weeksend_Series_Complete_Pfizer - weekstart_Series_Complete_Pfizer)]

#### USE SPATIAL KD-TREES TO COMPUTE POPULATION TO VACCINATION SITE DISTANCE MEASURES ####

setkey(cbgpopcen, LONGITUDE, LATITUDE)
cbgpopcen[, cbg_idx := .I]
cbgpopcen[, fips := sprintf("%02d", STATEFP)]
setnames(cbgpopcen, "POPULATION", "population")
setkey(vaccinesites, lng, lat)
vaccinesites[, vacsite_idx := .I]

# Use nearest-neighbor spatial joining to determine the closest vaccination site to each Census Block Group population center

nearest.sites <- nn2(data = vaccinesites[, .(lng, lat)], 
                     query = cbgpopcen[, .(LONGITUDE, LATITUDE)], k = 1, treetype = "kd", searchtype = "standard")
dt.nearest.sites <- data.table(cbg_idx = cbgpopcen$cbg_idx, closest_vaccine_site_miles = unlist(nearest.sites[2]) / 0.01455491)
cbg.nearest.sites <- merge(cbgpopcen, dt.nearest.sites, by = "cbg_idx")

# Distance to the nearest vaccination site for various percentiles of the state population

setorder(cbg.nearest.sites, fips, closest_vaccine_site_miles)
cbg.nearest.sites[, cumulpop := cumsum(population), by = .(fips)]
cbg.nearest.sites[, cumulpop_pctl := cumulpop / max(cumulpop), by = fips]

cbg.nearest.sites[cumulpop_pctl > 0.49 & cumulpop_pctl < 0.51, miles_vacsite_50th_pctl := mean(closest_vaccine_site_miles), by = fips]
cbg.nearest.sites[cumulpop_pctl > 0.94 & cumulpop_pctl < 0.96, miles_vacsite_95th_pctl := mean(closest_vaccine_site_miles), by = fips]

percentiles.closest.vacsite <- cbg.nearest.sites[, lapply(.SD, mean, na.rm = TRUE), by = .(fips), .SDcols = c(
  "miles_vacsite_50th_pctl", "miles_vacsite_95th_pctl")]

# Clean up the workspace

rm(cbgpopcen, vaccinesites, nearest.sites, dt.nearest.sites, cbg.nearest.sites)

#### COMBINE THE VARIOUS DATA INTO A SINGLE PANEL, INCLUDING BOTH TIME-VARYING AND CROSS-SECTIONAL/PRE-DETERMINED VARIABLES ####

setwd(datadir)

# Form the base panel

panel <- CJ(fips = state2fips$st, date = unique(c(covid$date, vaccinations$date)))
panel <- merge(panel, state2fips, by.x = "fips", by.y = "st")
panel[, fips := sprintf("%02d", fips)]

# Merge to panel the state population and population density for 2020

setnames(popdensity, "Name", "stname")
popdensity[, population_2020 := as.integer(gsub(",", "", `Resident Population`, fixed = TRUE))]
popdensity[, popdensity_2020 := as.numeric(gsub(",", "", `Resident Population Density`, fixed = TRUE))]
popdensity <- popdensity[, .(stname, population_2020, popdensity_2020)]
panel <- merge(panel, popdensity, by = "stname")

# Calculate and merge to panel the total state population that is 18 or older

population_age_groups <- vaccinations[date == max(date), .(
  Location, 
  population_2020_18p =  as.integer(round(100000 * Administered_18Plus / Admin_Per_100k_18Plus)),
  population_2020_12p =  as.integer(round(100000 * Administered_12Plus / Admin_Per_100k_12Plus)))]
population_age_groups[, population_2020_12to17 := population_2020_12p - population_2020_18p]
population_age_groups$population_2020_12p <- NULL
panel <- merge(panel, population_age_groups, by.x = "stusps", by.y = "Location")

# Merge to panel the state gross domestic product for 2020

gdp[, fips := substr(GeoFIPS, 1, 2)]
gdp[, gdp_million_2020 := as.numeric(`2020`)]
gdp <- gdp[, .(fips, gdp_million_2020)]
panel <- merge(panel, gdp, by = "fips")
panel[, gdp_per_capita_2020 := round(1000000 * gdp_million_2020 / population_2020)]

# Merge to panel the state presidential elections results for 2020

setnames(elections, c("stname", "votes_gop_2020", "votes_dem_2020", "total_votes_2020"))
elections[, gop_pct_2020 := round(100000 * votes_gop_2020 / total_votes_2020) / 1000]
panel <- merge(panel, elections, by = "stname")

# Merge to panel the state influenza vaccination rates for 2019

influenza[, fips := sprintf("%02d", fips)]
setnames(influenza, "analysis_value", "influenza_vaccination_pct_2019")
influenza <- influenza[, .(fips, influenza_vaccination_pct_2019)]
panel <- merge(panel, influenza, by = "fips")

# Merge to panel the state community mobility indexes by date

setnames(mobility, "sub_region_1", "stname")
mobility[, moveidx_retail_recreation := as.integer(retail_and_recreation_percent_change_from_baseline)]
mobility[, moveidx_grocery_pharmacy := as.integer(grocery_and_pharmacy_percent_change_from_baseline)]
mobility[, moveidx_parks := as.integer(parks_percent_change_from_baseline)]
mobility[, moveidx_transit := as.integer(transit_stations_percent_change_from_baseline)]
mobility[, moveidx_workplaces := as.integer(workplaces_percent_change_from_baseline)]
mobility[, moveidx_residential := as.integer(residential_percent_change_from_baseline)]
mobility <- mobility[, .(stname, date, moveidx_retail_recreation, moveidx_grocery_pharmacy,
                                       moveidx_parks, moveidx_transit, moveidx_workplaces, moveidx_residential)]
panel <- merge(panel, mobility, by = c("stname", "date"), all.x = TRUE)

# Merge to panel the computed distance measures from population to vaccination sites

panel <- merge(panel, percentiles.closest.vacsite, by = "fips")

# Merge to panel the state COVID-19 cases and deaths by date

covid <- covid[, .(state, date, tot_cases, new_case, tot_death, new_death)]
setnames(covid, c("stusps", "date", "covid_total_cases", "covid_new_cases",
                  "covid_total_deaths", "covid_new_deaths"))
panel <- merge(panel, covid, by = c("stusps", "date"), all.x = TRUE)
panel[, covid_total_cases_per100kpop := covid_total_cases / (population_2020 / 100000)]
panel[, covid_total_deaths_per100kpop := covid_total_deaths / (population_2020 / 100000)]
panel[, covid_new_cases_per100kpop := covid_new_cases / (population_2020 / 100000)]
panel[, covid_new_deaths_per100kpop := covid_new_deaths / (population_2020 / 100000)]

# Merge to panel the state COVID-19 hospitalizations by date

setnames(hospitalizations, "state", "stusps")
setnames(hospitalizations, "staffed_icu_adult_patients_confirmed_and_suspected_covid", "covid_daily_icu_patients")

hospitalizations <- hospitalizations[date >= "2020-07-15", .(stusps, date, covid_daily_icu_patients)]
hospitalizations[is.na(hospitalizations)] <- 0
setkey(hospitalizations, stusps, date)

hospitalizations[, covid_total_icu_patient_days := cumsum(covid_daily_icu_patients), by = stusps]

panel <- merge(panel, hospitalizations, all.x = TRUE, by = c("stusps", "date"))
panel[, covid_icu_patdays_per100kpop := covid_total_icu_patient_days / (population_2020 / 100000)]

#### DEFINE MEASURES OF STATE VACCINATIONS AND MERGE TO THE PANEL ####

# The earliest complete day of the vaccination panel is Feb 19, 2021 (see DESCRIPTION)

vaccinations_m <- vaccinations[date >= "2021-02-19", 
                               .(Location, date, Administered_Dose1_Recip, Administered_Janssen, Administered_Moderna, 
                                 Administered_Pfizer, Series_Complete_Moderna, Series_Complete_Pfizer, 
                                 Administered_Dose1_Recip_18Plus)]

setnames(vaccinations_m, "Location", "stusps")
setnames(vaccinations_m, "Administered_Dose1_Recip", "dose1_administered")
setnames(vaccinations_m, "Administered_Janssen", "dose1_janssen_administered") # Janssen only has one dose, but consistent in naming
setnames(vaccinations_m, "Administered_Moderna", "moderna_administered")
setnames(vaccinations_m, "Administered_Pfizer", "pfizer_administered")
setnames(vaccinations_m, "Series_Complete_Moderna", "dose2_moderna_administered")
setnames(vaccinations_m, "Series_Complete_Pfizer", "dose2_pfizer_administered")
setnames(vaccinations_m, "Administered_Dose1_Recip_18Plus", "dose1_administered_18p")

vaccinations_m[, dose1_administered := as.numeric(dose1_administered)]
vaccinations_m[, dose1_janssen_administered := as.numeric(dose1_janssen_administered)]
vaccinations_m[, moderna_administered := as.numeric(moderna_administered)]
vaccinations_m[, pfizer_administered := as.numeric(pfizer_administered)]
vaccinations_m[, dose2_moderna_administered := as.numeric(dose2_moderna_administered)]
vaccinations_m[, dose2_pfizer_administered := as.numeric(dose2_pfizer_administered)]
vaccinations_m[, dose1_administered_18p := as.numeric(dose1_administered_18p)]

# Calculate the Moderna and Pfizer dose 1 administered using the total and dose 2 values by manufacturer

vaccinations_m[, dose1_moderna_administered := moderna_administered - dose2_moderna_administered]
vaccinations_m[, dose1_pfizer_administered := pfizer_administered - dose2_pfizer_administered]

# Calculate various measures of vaccinations per 100 people

vaccinations_m <- merge(vaccinations_m, panel[, .(stusps, date, population_2020, population_2020_18p)], 
                        by = c("stusps", "date"))

vaccinations_m[, dose1_per_100pop := dose1_administered / (population_2020 / 100)]
vaccinations_m[, dose1_janssen_per_100pop := dose1_janssen_administered / (population_2020 / 100)]
vaccinations_m[, dose1_moderna_per_100pop := dose1_moderna_administered / (population_2020 / 100)]
vaccinations_m[, dose1_pfizer_per_100pop := dose1_pfizer_administered / (population_2020 / 100)]
vaccinations_m[, dose2_moderna_per_100pop := dose2_moderna_administered / (population_2020 / 100)]
vaccinations_m[, dose2_pfizer_per_100pop := dose2_pfizer_administered / (population_2020 / 100)]
vaccinations_m[, dose1_18p_per_100pop := dose1_administered_18p / (population_2020_18p / 100)]

# Subset columns and merge to the panel

vaccinations_m <- vaccinations_m[, .(stusps, date, dose1_administered, dose1_janssen_administered, dose1_moderna_administered, 
                                     dose1_pfizer_administered, dose2_moderna_administered, dose2_pfizer_administered, 
                                     dose1_per_100pop, dose1_janssen_per_100pop, dose1_moderna_per_100pop, dose1_pfizer_per_100pop, 
                                     dose2_moderna_per_100pop, dose2_pfizer_per_100pop, 
                                     dose1_administered_18p, dose1_18p_per_100pop)]

panel <- merge(panel, vaccinations_m, by = c("stusps", "date"), all.x = TRUE)
rm(vaccinations_m)

#### DEFINE THE TREATMENT INDICATORS FOR STATE INCENTIVE SCHEMES FOR VACCINATIONS ####

panel[, incentive_scheme := FALSE]
panel[stname == "Ohio" & date >= "2021-05-12", incentive_scheme := TRUE]

panel[stname == "Maryland" & date >= "2021-05-20", incentive_scheme := TRUE]         #  9 days after Ohio's announcement
panel[stname == "New York" & date >= "2021-05-20", incentive_scheme := TRUE]         #  9 days after Ohio's announcement
panel[stname == "Oregon" & date >= "2021-05-21", incentive_scheme := TRUE]           # 10 days after Ohio's announcement
panel[stname == "Delaware" & date >= "2021-05-24", incentive_scheme := TRUE]         # 13 days after Ohio's announcement
panel[stname == "Arkansas" & date >= "2021-05-25", incentive_scheme := TRUE]         # 14 days after Ohio's announcement
panel[stname == "Colorado" & date >= "2021-05-25", incentive_scheme := TRUE]         # 14 days after Ohio's announcement
panel[stname == "California" & date >= "2021-05-27", incentive_scheme := TRUE]       # 16 days after Ohio's announcement
panel[stname == "West Virginia" & date >= "2021-05-27", incentive_scheme := TRUE]    # 16 days after Ohio's announcement
panel[stname == "New Mexico" & date >= "2021-06-01", incentive_scheme := TRUE]       # 21 days after Ohio's announcement
panel[stname == "Washington" & date >= "2021-06-03", incentive_scheme := TRUE]       # 23 days after Ohio's announcement
panel[stname == "Kentucky" & date >= "2021-06-04", incentive_scheme := TRUE]         # 24 days after Ohio's announcement
panel[stname == "North Carolina" & date >= "2021-06-10", incentive_scheme := TRUE]   # 30 days after Ohio's announcement
panel[stname == "Massachusetts" & date >= "2021-06-15", incentive_scheme := TRUE]    # 35 days after Ohio's announcement
panel[stname == "Illinois" & date >= "2021-06-16", incentive_scheme := TRUE]         # 36 days after Ohio's announcement
panel[stname == "Louisiana" & date >= "2021-06-17", incentive_scheme := TRUE]        # 36 days after Ohio's announcement
panel[stname == "Maine" & date >= "2021-06-17", incentive_scheme := TRUE]            # 36 days after Ohio's announcement
panel[stname == "Nevada" & date >= "2021-06-17", incentive_scheme := TRUE]           # 37 days after Ohio's announcement

# --- Ohio's Vax-A-Million ended on June 20, 2021 --- 40 days after Ohio's announcement

panel[stname == "Michigan" & date >= "2021-07-01", incentive_scheme := TRUE]         # 51 days after Ohio's announcement
panel[stname == " Missouri" & date >= "2021-07-21", incentive_scheme := TRUE]        # 71 days after Ohio's announcement

donor.pool.cutoff.date <- "2021-06-20"

panel[, ever_scheme := max(incentive_scheme), by = stname]
panel[, ever_scheme := ifelse(ever_scheme == 1, TRUE, FALSE)]
panel[date < donor.pool.cutoff.date, temp_not_donor_pool := incentive_scheme]
panel[, donor_pool := 1 - max(temp_not_donor_pool, na.rm = T), by = fips]
panel[, donor_pool := ifelse(donor_pool == 1, TRUE, FALSE)]
panel$temp_not_donor_pool <- NULL
panel[, ohio_post := ifelse(stname == "Ohio" & date >= "2021-05-12", TRUE, FALSE)]

# Clean up the workspace

rm(vaccinations, covid, hospitalizations, popdensity, population_age_groups,
   gdp, elections, influenza, mobility, state2fips, percentiles.closest.vacsite)

#### SAVE COMPILED DATA FOR ANALYSIS AS CSV ####

setwd(datadir)

setcolorder(panel, c("stname", "fips", "stusps", "date", "donor_pool", "ever_scheme", 
                     "incentive_scheme", "ohio_post", "population_2020", "population_2020_18p", "population_2020_12to17"))

setkey(panel, stname, fips, stusps, date) # Sort the panel by these variables

# Save the panel data as CSV format

fwrite(panel, "analysis_panel.csv")

# Form the base of the data dictionary, which then is completed by hand to add sources and notes.

data.dict <- data.table(
  Column = names(panel),
  Type = lapply(panel, class),
  Varies = t(panel[stname == "Ohio" & date == "2021-05-12"]) == t(panel[stname == "Ohio" & date == "2021-06-19"]),
  Example = t(panel[stname == "Ohio" & date == "2021-05-12"])
)
setnames(data.dict, "Varies.V1", "Varies")
data.dict[, Varies := ifelse(Varies == TRUE, "fixed", "daily")]
setnames(data.dict, "Example.V1", "Example")
data.dict[, c("Description", "Source", "Notes") := " "]
data.dict

fwrite(data.dict, "base_data_dictionary_columns.csv")

# Summarize the date range of main outcome variables in the panel

summary(panel$date)
summary(panel[dose1_per_100pop > 0]$date)
summary(panel[covid_total_cases_per100kpop > 0]$date)
summary(panel[covid_icu_patdays_per100kpop > 0]$date)

#### END ####
