# Updated 2021 December 15

#### CODE PREAMBLE AND DESCRIPTION ####

## Code preamble: prepare workspace and load R packages

rm(list = ls())     # Clear workspace
library(dplyr)      # R packages used in forming tables
library(huxtable)   # R package for saving LaTex tables
library(augsynth)   # R package for synthetic control estimation
library(ggplot2)    # R package for plotting graphs
library(data.table) # R package for using data.tables as augmented data.frames
datadir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/data" # SET THIS: top-level data directory
figuresdir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/figures" # SET THIS: directory in which to save figures
tablesdir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/tables" # SET THIS: directory in which to save tables
setwd(datadir)

## List of figures:
#
#  - Synthetic Control time series graph: total dose 1 vaccinations per 100 state population by region
#  - Synthetic Control difference graph: total dose 1 vaccinations per 100 state population
#
#  - Synthetic Control difference graph: total dose 1 vaccinations per 100 state population -- 18 and older
#
#  - Synthetic Control time series graph: total COVID-19 cases per 100,000 population by region
#  - Synthetic Control difference graph: total COVID-19 cases per 100,000 population
#
#  - Synthetic Control time series graph: cumulative total COVID-19 ICU patient-days per 100,000 population by region
#  - Synthetic Control difference graph: cumulative total COVID-19 ICU patient-days per 100,000 population
#
#  - Single figure showing the post-treatment estimated effects of the three outcomes over time all on the same scale
#

## List of tables:
#
#  - Largest five unit weights for the Synthetic Ohio using dose 1 vaccinations per 100 state population
#  - Full table of control unit weights for all Synthetic Control outcomes
#
#  - Summary statistics for the United States, Ohio, and Synthetic Ohio
#
#  - Synthetic Control results table for all outcomes with estimated difference and 95 percent C.I. range
#
#  - Aggregate estimated effects and characteristics for Ohio table
#

## Data and programming notes:
#
# 1. Running this code requires fairly little computer RAM, less than 1 GB. 
#
# 2. The data are a balanced panel of the 50 states and D.C., with data starting:
#     - February 19, 2021 for dose 1 vaccinations (Pfizer and Moderna, as this was pre-Janssen)
#     - March 4, 2021 for dose 2 outcomes (Pfizer and Moderna), earliest non-zero values in CDC's data
#     - March 5, 2021 for Janssen vaccinations (always dose 1)
#     - February 19, 2021 for COVID-19 outcomes (authors' decision, to be consistent)
#       The full panel of data has COVID-19 outcomes starting March 1, 2020
# 
# 3. June 20, 2021 was the end-date for Ohio's vaccine incentive program.
#

#### LOAD AND PREPARE DATA ####

panel <- fread("analysis_panel.csv")
setkey(panel, fips, date)

# Subset the panel to data after the starting date and keep only Ohio and the donor pool of states

mindate.panel = "2021-02-19"
maxdate.vaccinations <- max((panel[!is.na(dose1_per_100pop)]$date))
maxdate.cases <- max((panel[!is.na(covid_new_cases)]$date))
maxdate.icu <- max((panel[!is.na(covid_icu_patdays_per100kpop)]$date))

synthpanel.dose1 <- panel[(fips == 39 | donor_pool == 1) & date >= mindate.panel & date <= maxdate.vaccinations]
synthpanel.cases <- panel[(fips == 39 | donor_pool == 1) & date >= mindate.panel & date <= maxdate.cases]
synthpanel.icu <- panel[(fips == 39 | donor_pool == 1) & date >= mindate.panel & date <= maxdate.icu]

#### CONDUCT THE SYNTHETIC CONTROL ESTIMATIONS FOR EACH OUTCOME OF INTEREST ####

# Estimation: total dose 1 vaccinations per 100 state population

est.synth.dose1 <- 
  augsynth(dose1_per_100pop ~ ohio_post |
             popdensity_2020 +
             gdp_per_capita_2020 +
             gop_pct_2020 +
             influenza_vaccination_pct_2019 +
             moveidx_retail_recreation +
             moveidx_grocery_pharmacy +
             moveidx_parks +
             moveidx_transit +
             moveidx_workplaces +
             moveidx_residential +
             miles_vacsite_50th_pctl +
             miles_vacsite_95th_pctl
           , unit = fips, time = date, data = synthpanel.dose1, progfun = "Ridge", fixedeff = TRUE)

# Estimation: total dose 1 vaccinations per 100 state population -- 18 and older

est.synth.dose1.18p <- 
  augsynth(dose1_18p_per_100pop ~ ohio_post |
             popdensity_2020 +
             gdp_per_capita_2020 +
             gop_pct_2020 +
             influenza_vaccination_pct_2019 +
             moveidx_retail_recreation +
             moveidx_grocery_pharmacy +
             moveidx_parks +
             moveidx_transit +
             moveidx_workplaces +
             moveidx_residential +
             miles_vacsite_50th_pctl +
             miles_vacsite_95th_pctl
           , unit = fips, time = date, data = synthpanel.dose1, progfun = "Ridge", fixedeff = TRUE)

# Estimation: total COVID-19 cases per 100,000 state population

est.synth.cases <- 
  augsynth(covid_total_cases_per100kpop ~ ohio_post |
             popdensity_2020 +
             gdp_per_capita_2020 +
             gop_pct_2020 +
             influenza_vaccination_pct_2019 +
             moveidx_retail_recreation +
             moveidx_grocery_pharmacy +
             moveidx_parks +
             moveidx_transit +
             moveidx_workplaces +
             moveidx_residential +
             miles_vacsite_50th_pctl +
             miles_vacsite_95th_pctl
           , unit = fips, time = date, data = synthpanel.cases, progfun = "Ridge", fixedeff = TRUE)

# Estimation: cumulative total COVID-19 ICU patient-days per 100,000 population

est.synth.icu <- 
  augsynth(covid_icu_patdays_per100kpop ~ ohio_post |
             popdensity_2020 +
             gdp_per_capita_2020 +
             gop_pct_2020 +
             influenza_vaccination_pct_2019 +
             moveidx_retail_recreation +
             moveidx_grocery_pharmacy +
             moveidx_parks +
             moveidx_transit +
             moveidx_workplaces +
             moveidx_residential +
             miles_vacsite_50th_pctl +
             miles_vacsite_95th_pctl
           , unit = fips, time = date, data = synthpanel.icu, progfun = "Ridge", fixedeff = TRUE)

#### CONDUCT THE INFERENCE AND EXTRACT THE CONTROL UNIT WEIGHTS ####

# Conformal inference

summary.est.synth.dose1 <- summary(est.synth.dose1, inf = TRUE, inf_type = "conformal")

summary.est.synth.dose1.18p <- summary(est.synth.dose1.18p, inf = TRUE, inf_type = "conformal")

summary.est.synth.cases <- summary(est.synth.cases, inf = TRUE, inf_type = "conformal")

summary.est.synth.icu <- summary(est.synth.icu, inf = TRUE, inf_type = "conformal")

# Extract control unit weights

synth.weights.dose1 <- cbind(unique(synthpanel.dose1[fips != 39, .(stname, fips)]), est.synth.dose1$weights)
setnames(synth.weights.dose1, "V1", "unit_weight_dose1")
setorder(synth.weights.dose1, -unit_weight_dose1)

synth.weights.dose1.18p <- cbind(unique(synthpanel.dose1[fips != 39, .(stname, fips)]), est.synth.dose1.18p$weights)
setnames(synth.weights.dose1.18p, "V1", "unit_weight_dose1_18p")
setorder(synth.weights.dose1.18p, -unit_weight_dose1_18p)

synth.weights.cases <- cbind(unique(synthpanel.cases[fips != 39, .(stname, fips)]), est.synth.cases$weights)
setnames(synth.weights.cases, "V1", "unit_weight_cases")
setorder(synth.weights.cases, -unit_weight_cases)

synth.weights.icu <- cbind(unique(synthpanel.icu[fips != 39, .(stname, fips)]), est.synth.icu$weights)
setnames(synth.weights.icu, "V1", "unit_weight_icu")
setorder(synth.weights.icu, -unit_weight_icu)

#### CONSTRUCT THE DATA OF THE TIME SERIES FOR EACH OUTCOME BY TREATED / SYNTHETIC CONTROL / NATIONAL ####

#  Note: because the augsynth estimation includes unit fixed effects, 
#   the predicted synthetic outcome by date does NOT equal the sum(weights * outcome) by date for donor states. 
#   Instead, follow this approach adopted from the augsynth source code

ts.data <- synthpanel.dose1[date >= mindate.panel & (fips == 39 | donor_pool == 1), 
                 .(stname, fips, date, dose1_per_100pop, dose1_18p_per_100pop,
                   covid_total_cases_per100kpop, covid_icu_patdays_per100kpop)]

# Total dose 1 vaccinations per 100 state population

ts.data <- merge(ts.data, synth.weights.dose1[, .(fips, unit_weight_dose1)], all.x = TRUE, by = "fips")
ts.data[date >= mindate.panel & date < "2021-05-12", pre_mean_dose1 := mean(dose1_per_100pop), by = "fips"]
ts.data[date >= mindate.panel, pre_mean_dose1 := max(pre_mean_dose1, na.rm = TRUE), by = fips]
ts.data[, wtd_demeaned_dose1 := unit_weight_dose1 * (dose1_per_100pop - pre_mean_dose1)]

# Total dose 1 vaccinations per 100 state population -- 18 and older

ts.data <- merge(ts.data, synth.weights.dose1.18p[, .(fips, unit_weight_dose1_18p)], all.x = TRUE, by = "fips")
ts.data[date >= mindate.panel & date < "2021-05-12", pre_mean_dose1_18p := mean(dose1_18p_per_100pop), by = "fips"]
ts.data[date >= mindate.panel, pre_mean_dose1_18p := max(pre_mean_dose1_18p, na.rm = TRUE), by = fips]
ts.data[, wtd_demeaned_dose1_18p := unit_weight_dose1_18p * (dose1_18p_per_100pop - pre_mean_dose1_18p)]

# Total COVID-19 cases per 100,000 state population

ts.data <- merge(ts.data, synth.weights.cases[, .(fips, unit_weight_cases)], all.x = TRUE, by = "fips")
ts.data[date >= mindate.panel & date < "2021-05-12", pre_mean_cases := mean(covid_total_cases_per100kpop), by = "fips"]
ts.data[date >= mindate.panel, pre_mean_covid_cases := max(pre_mean_cases, na.rm = TRUE), by = fips]
ts.data[, wtd_demeaned_cases := unit_weight_cases * (covid_total_cases_per100kpop - pre_mean_covid_cases)]

# cumulative total COVID-19 ICU patient-days per 100,000 population

ts.data <- merge(ts.data, synth.weights.icu[, .(fips, unit_weight_icu)], all.x = TRUE, by = "fips")
ts.data[date >= mindate.panel & date < "2021-05-12", pre_mean_icu := mean(covid_icu_patdays_per100kpop), by = "fips"]
ts.data[date >= mindate.panel, pre_mean_icu := max(pre_mean_icu, na.rm = TRUE), by = fips]
ts.data[, wtd_demeaned_icu := unit_weight_icu * (covid_icu_patdays_per100kpop - pre_mean_icu)]

# Collapse data into the synthetic control outcome data by date

ohio.pretreatment.means <- ts.data[fips == 39, lapply(.SD, max, na.rm = TRUE), 
                                   .SDcols = c("pre_mean_dose1", "pre_mean_dose1_18p", "pre_mean_cases", "pre_mean_icu")]

synth.outcomes <- ts.data[fips != 39, lapply(.SD, sum), by = date, 
                          .SDcols = c("wtd_demeaned_dose1", "wtd_demeaned_dose1_18p", "wtd_demeaned_cases","wtd_demeaned_icu")]
synth.outcomes <- synth.outcomes[, .(region = "Synthetic Ohio", date, 
                                     dose1_per_100pop = wtd_demeaned_dose1 + ohio.pretreatment.means$pre_mean_dose1,
                                     dose1_18p_per_100pop = wtd_demeaned_dose1_18p + ohio.pretreatment.means$pre_mean_dose1_18p,
                                     covid_total_cases_per100kpop = wtd_demeaned_cases + ohio.pretreatment.means$pre_mean_cases,
                                     covid_icu_patdays_per100kpop = wtd_demeaned_icu + ohio.pretreatment.means$pre_mean_icu)]

# Append the actual Ohio data and the national-level values

ohio.outcomes <- panel[date >= mindate.panel & fips == 39, 
                       .(region = "Ohio", date, dose1_per_100pop, dose1_18p_per_100pop, covid_total_cases_per100kpop, covid_icu_patdays_per100kpop)]

national.outcomes <- panel[date >= mindate.panel, .(region = "National",
                             dose1_per_100pop = sum(dose1_administered) / sum(population_2020 / 100),
                             dose1_18p_per_100pop = sum(dose1_administered_18p) / sum(population_2020_18p / 100),
                             covid_total_cases_per100kpop = sum(covid_total_cases) / (sum(population_2020) / 100000),
                             covid_icu_patdays_per100kpop = sum(covid_total_icu_patient_days) / sum(population_2020 / 100000)
                             ), by = date]

outcomes.panel <- rbind(synth.outcomes, ohio.outcomes, national.outcomes)

# Clean up the workspace

rm(ts.data, ohio.pretreatment.means, synth.outcomes, ohio.outcomes, national.outcomes, synthpanel.dose1, synthpanel.cases, synthpanel.icu)

#### FIGURES: TIME SERIES BY REGION AND DIFFERENCE OHIO MINUS SYNTHETIC CONTROL: TOTAL DOSE 1 VACCINATIONS PER 100 POP. ####

# Time series graph for Ohio, Synthetic Ohio, and National values

ggplot(outcomes.panel[date > mindate.panel & date <= maxdate.vaccinations], 
       aes(x = date, group = region, color = region, linetype = region, y = dose1_per_100pop)) + 
  geom_line() +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  annotate("label", x = as.Date("2021-05-31"), y = 17, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12.\nEntry ended on June 20.", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "Share of population vaccinated (%)", breaks = c(10, 20, 30, 40, 50), limits = c(10, 55)) +
  scale_linetype_manual(name = "Region", values = c("dotted", "solid", "dashed")) +
  scale_color_manual(name = "Region", values = c("grey60", "#BB0000", "black")) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.15, 0.75))

ggsave(file.path(figuresdir, "Population_Share_Any_Vaccination.pdf"), width = 8, height = 4, units = "in", dpi = 300)

# Difference graph for Ohio minus Synthetic Ohio

ggplot(data.table(summary.est.synth.dose1$att)) + 
  geom_ribbon(aes(x = Time, ymin = lower_bound, ymax = upper_bound), color = "grey85", fill = "grey85") +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  geom_line(aes(x = Time, y = Estimate)) +
  annotate("label", x = as.Date("2021-05-31"), y = -0.5, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12.\nEntry ended on June 20.", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "Estimated difference", limits = c(-1, 2), breaks = c(-1, 0, 1, 2)) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"))

ggsave(file.path(figuresdir, "Population_Share_Any_Vaccination_Difference.pdf"), width = 8, height = 4, units = "in", dpi = 300)

#### FIGURES: TIME SERIES BY REGION AND DIFFERENCE OHIO MINUS SYNTHETIC CONTROL: TOTAL DOSE 1 VACCINATIONS PER 100 POP. -- 18 AND OLDER ####

# Time series graph for Ohio, Synthetic Ohio, and National values

ggplot(outcomes.panel[date > mindate.panel & date <= maxdate.vaccinations], 
       aes(x = date, group = region, color = region, linetype = region, y = dose1_18p_per_100pop)) + 
  geom_line() +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  annotate("label", x = as.Date("2021-05-31"), y = 17, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12.\nEntry ended on June 20.", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "Share of population vaccinated (%)", breaks = c(10, 30, 50, 70), limits = c(10, 70)) +
  scale_linetype_manual(name = "Region", values = c("dotted", "solid", "dashed")) +
  scale_color_manual(name = "Region", values = c("grey60", "#BB0000", "black")) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.15, 0.75))

ggsave(file.path(figuresdir, "Population_Share_Any_Vaccination_18Older.pdf"), width = 8, height = 4, units = "in", dpi = 300)

# Difference graph for Ohio minus Synthetic Ohio

ggplot(data.table(summary.est.synth.dose1.18p$att)) + 
  geom_ribbon(aes(x = Time, ymin = lower_bound, ymax = upper_bound), color = "grey85", fill = "grey85") +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  geom_line(aes(x = Time, y = Estimate)) +
  annotate("label", x = as.Date("2021-05-31"), y = -0.5, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12.\nEntry ended on June 20.", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "Estimated difference", limits = c(-1, 2), breaks = c(-1, 0, 1, 2)) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"))

ggsave(file.path(figuresdir, "Population_Share_Any_Vaccination_Difference_18Older.pdf"), width = 8, height = 4, units = "in", dpi = 300)

#### FIGURES: TIME SERIES BY REGION AND DIFFERENCE OHIO MINUS SYNTHETIC CONTROL: TOTAL COVID-19 CASES PER 100,000 POP. ####

# Time series graph for Ohio, Synthetic Ohio, and National values

ggplot(outcomes.panel[date >= mindate.panel & date <= maxdate.cases], 
       aes(x = date, group = region, color = region, linetype = region, y = covid_total_cases_per100kpop)) + 
  geom_line() +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  annotate("label", x = as.Date("2021-05-31"), y = 8300, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12.\nEntry ended on June 20.", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "Recorded cases per 100,000 population", breaks = c(8000, 8500, 9000, 9500, 10000), 
                     labels = c("8,000", "8,500", "9,000", "9,500", "10,000"), limits = c(8000, 10000)) +
  scale_linetype_manual(name = "Region", values = c("dotted", "solid", "dashed")) +
  scale_color_manual(name = "Region", values = c("grey60", "#BB0000", "black")) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.15, 0.75))

ggsave(file.path(figuresdir, "COVID19_Cases_Per_100k.pdf"), width = 8, height = 4, units = "in", dpi = 300)

# Difference graph for Ohio minus Synthetic Ohio

ggplot(data.table(summary.est.synth.cases$att)) + 
  geom_ribbon(aes(x = Time, ymin = lower_bound, ymax = upper_bound), color = "grey85", fill = "grey85") +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  geom_line(aes(x = Time, y = Estimate)) +
  annotate("label", x = as.Date("2021-05-31"), y = -110, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12.\nEntry ended on June 20.", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "Estimated difference", limits = c(-175, 75), breaks = c(-150, -75, 0, 75)) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"))

ggsave(file.path(figuresdir, "COVID19_Cases_Per_100k_Difference.pdf"), width = 8, height = 4, units = "in", dpi = 300)

#### FIGURES: TIME SERIES BY REGION AND DIFFERENCE OHIO MINUS SYNTHETIC CONTROL: TOTAL COVID-19 ICU PATIENT-DAYS PER 100K POP. ####

# Time series graph for Ohio, Synthetic Ohio, and National values

ggplot(outcomes.panel[date >= mindate.panel & date <= maxdate.icu], 
       aes(x = date, group = region, color = region, linetype = region, y = covid_icu_patdays_per100kpop)) + 
  geom_line() +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  annotate("label", x = as.Date("2021-05-31"), y = 1180, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12.\nEntry ended on June 20.", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "ICU patient-days per 100,000 population", breaks = c(1100, 1250, 1400, 1550), limits = c(1100, 1605)) +
  scale_linetype_manual(name = "Region", values = c("dotted", "solid", "dashed")) +
  scale_color_manual(name = "Region", values = c("grey60", "#BB0000", "black")) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.15, 0.75))

ggsave(file.path(figuresdir, "COVID19_ICU_Patient_Days_Per_100k.pdf"), width = 8, height = 4, units = "in", dpi = 300)

# Difference graph for Ohio minus Synthetic Ohio

ggplot(data.table(summary.est.synth.icu$att)) + 
  geom_ribbon(aes(x = Time, ymin = lower_bound, ymax = upper_bound), color = "grey85", fill = "grey85") +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  geom_line(aes(x = Time, y = Estimate)) +
  annotate("label", x = as.Date("2021-05-31"), y = -37, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12.\nEntry ended on June 20.", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "Estimated difference", limits = c(-56, 25), breaks = c(-50, -25, 0, 25)) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"))

ggsave(file.path(figuresdir, "COVID19_ICU_Patient_Days_Per_100k_Difference.pdf"), width = 8, height = 4, units = "in", dpi = 300)

#### FIGURE: POST-TREATMENT ESTIMATED EFFECTS OF ALL THREE OUTCOMES OVER TIME ON THE SAME SCALE ####

# Form the graph data

post.effects <- rbind(
  data.table(outcome = "1 vaccinations", summary.est.synth.dose1$att),
  data.table(outcome = "2 cases", summary.est.synth.cases$att),
  data.table(outcome = "3 icu", summary.est.synth.icu$att)
)

post.effects[, pt_days := as.integer(ceiling(difftime(Time, "2021-05-12", units = "days"))) + 1]
post.effects[outcome == "1 vaccinations", effect := Estimate * 1000]
post.effects[outcome == "2 cases", effect := Estimate * -1]
post.effects[outcome == "3 icu", effect := Estimate * -1]
post.effects[, signif := ifelse(lower_bound * upper_bound > 0, "Yes", "No")]

post.effects <- post.effects[pt_days >= 0, .(pt_days, outcome, effect, signif)]

# Graph the effects for the three outcomes over time in the post-treatment period

ggplot() +
  geom_vline(xintercept = 40, linetype = "dashed") +
  geom_point(data = post.effects[signif == "Yes"], aes(x = pt_days, y = effect, group = outcome, shape = outcome), size = 1.5, color = "#BB0000") +
  geom_point(data = post.effects[signif == "No" & outcome == "1 vaccinations"], aes(x = pt_days, y = effect), size = 1.5, shape = 21, color = "grey60") +
  geom_point(data = post.effects[signif == "No" & outcome == "2 cases"], aes(x = pt_days, y = effect), size = 1.5, shape = 22, color = "grey60") +
  geom_point(data = post.effects[signif == "No" & outcome == "3 icu"], aes(x = pt_days, y = effect), size = 1.5, shape = 24, color = "grey60") +
  scale_shape_manual(name = "Outcome: solid shapes are statistically significant", values = c(19, 15, 17), 
                     labels = c("First dose vaccination compliers per 100,000 population", "Total COVID-19 cases prevented per 100,000 population", 
                                "Total ICU patient-days prevented per 100,000 population")) +
  scale_x_continuous(name = "Days after Ohio's Vax-A-Million announcement on May 12, 2021", breaks = 5 * 0:14, limits = c(0, 70)) +
  scale_y_continuous(name = "Estimated effect", limits = c(-50, 800), breaks = 100 * 0:8) +
  annotate("segment", x = 44.5, xend = 40.5, y = 250, yend = 250, arrow = arrow(length = unit(0.25, "cm")), color = "black", size = 0.5) +
  annotate("label", x = 52, y = 250, label = "Lottery entry ended June 20.", color = "black", size = 3) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"), legend.position = "top", legend.direction = "vertical")

ggsave(file.path(figuresdir, "Effects_By_Days_Post_Treatment_All_Outcomes.pdf"), width = 8, height = 6, units = "in", dpi = 300)

rm(post.effects)

#### TABLES: SYNTHETIC CONTROL UNIT DONOR WEIGHTS ####

# Prepare the table of top-5 state unit weights for the dose 1 outcome

setorder(synth.weights.dose1, -unit_weight_dose1)
synth.weights.dose1.top5 <- synth.weights.dose1[1:5, .(State = stname, `Unit weight` = sprintf("%0.3f", unit_weight_dose1))]

# Save the table as .tex using Huxtable

weightstable.top5 <- huxtable(synth.weights.dose1.top5) %>% 
  set_align(col = 1, value = "left") %>% set_align(col = 2, value = "center") %>%
  set_align(row = 1, col = 2, value = "center") %>%
  set_top_border(row = 1:2, col = everywhere) %>%
  set_bottom_border(row = 6, col = everywhere)
weightstable.top5
sink(file.path(tablesdir, "Synthetic_Unit_Weights_Top5.tex"))
print_latex(weightstable.top5, tabular_only = TRUE)
sink()

# Prepare the table of all weights for all outcomes

setkey(synth.weights.dose1, fips)
setkey(synth.weights.cases, fips)
setkey(synth.weights.icu, fips)

synth.weights.all.outcomes <- merge(synth.weights.dose1, synth.weights.cases[, .(fips, unit_weight_cases)], all = TRUE)
synth.weights.all.outcomes <- merge(synth.weights.all.outcomes, synth.weights.icu[, .(fips, unit_weight_icu)], all = TRUE)

synth.weights.all.outcomes$fips <- NULL
synth.weights.all.outcomes[, unit_weight_dose1 := sprintf("%0.3f", unit_weight_dose1)]
synth.weights.all.outcomes[, unit_weight_cases := sprintf("%0.3f", unit_weight_cases)]
synth.weights.all.outcomes[, unit_weight_icu := sprintf("%0.3f", unit_weight_icu)]
synth.weights.all.outcomes[synth.weights.all.outcomes == "NA"] <- "N/A"

setnames(synth.weights.all.outcomes, c(" ", "Vaccinations", "Cases", "ICU days"))

# Save the table as .tex using Huxtable

weightstable <- huxtable(synth.weights.all.outcomes) %>% 
  insert_row(c("State", "Unit weights for model", "", ""), after = 0) %>% merge_across(row = 1, col = 2:4) %>%
  set_align(col = 1, value = "left") %>% set_align(col = 2:4, value = "right") %>%
  set_align(row = 1, col = 2:4, value = "center") %>%
  set_bottom_border(row = 1, col = 2:4) %>%
  set_top_border(row = 1, col = everywhere) %>%
  set_bottom_border(row = 2, col = everywhere) %>%
  set_bottom_border(row = nrow(synth.weights.all.outcomes) + 2, col = everywhere) %>%
  set_all_padding(row = everywhere, col = everywhere, 0)
weightstable
font_size(weightstable) <- 8
sink(file.path(tablesdir, "Synthetic_Unit_Weights_All.tex"))
print_latex(weightstable, tabular_only = TRUE)
sink()

# Clean up the workspace

rm(synth.weights.dose1.top5, weightstable.top5, weightstable, synth.weights.all.outcomes)

#### TABLE: SUMMARY STATISTICS COMPARISON OF OHIO, SYNTHETIC OHIO, AND THE UNITED STATES NATIONALLY ####

# Compute selected statistics on the outcome variables by group

group.outcomes.dose1.april02 <- outcomes.panel[date == "2021-04-02", 
                                               .(region, dose1_per_100pop_april02 = dose1_per_100pop)]
group.outcomes.dose1.may12 <- outcomes.panel[date == "2021-05-12", 
                                             .(region, dose1_per_100pop_may12 = dose1_per_100pop)]
group.outcomes.cases.may12 <- outcomes.panel[date == "2021-05-12", 
                                             .(region, covid_total_cases_per100kpop_may12 = covid_total_cases_per100kpop)]
group.outcomes.icu.may12 <- outcomes.panel[date == "2021-05-12", 
                                                  .(region, covid_icu_patdays_per100kpop_may12 = covid_icu_patdays_per100kpop)]

group.outcomes.stats <-merge(group.outcomes.dose1.april02, group.outcomes.dose1.may12, by = "region")
group.outcomes.stats <-merge(group.outcomes.stats, group.outcomes.cases.may12, by = "region")
group.outcomes.stats <-merge(group.outcomes.stats, group.outcomes.icu.may12, by = "region")
group.outcomes.stats[region == "National", region := "State average"]

# Define the share of population aged 12 to 17, and the share aged 18 and older, by state

panel[, popshare_12to17 := 100 * population_2020_12to17 / population_2020]
panel[, popshare_18p := 100 * population_2020_18p / population_2020]

# Compute the (weighted) average for state covariates during the pre-treatment period by group

national.covariates <- panel[date >= mindate.panel & date <= "2021-05-12", lapply(.SD, mean), by = "stname", .SDcols = c(
  "popshare_12to17", "popshare_18p",
  "popdensity_2020", "gdp_per_capita_2020", "gop_pct_2020", "influenza_vaccination_pct_2019", "moveidx_retail_recreation", 
  "moveidx_grocery_pharmacy", "moveidx_parks", "moveidx_transit", "moveidx_workplaces" ,"moveidx_residential", "miles_vacsite_50th_pctl", 
  "miles_vacsite_95th_pctl")]
national.covariates$stname <- NULL
national.covariates <- national.covariates[, lapply(.SD, mean, na.rm = TRUE)]
national.covariates[, region := "State average"]

ohio.covariates <- panel[date >= mindate.panel & date <= "2021-05-12" & stname == "Ohio", lapply(.SD, mean), .SDcols = c(
  "popshare_12to17", "popshare_18p",
  "popdensity_2020", "gdp_per_capita_2020", "gop_pct_2020", "influenza_vaccination_pct_2019", "moveidx_retail_recreation", 
  "moveidx_grocery_pharmacy", "moveidx_parks", "moveidx_transit", "moveidx_workplaces" ,"moveidx_residential", "miles_vacsite_50th_pctl", 
  "miles_vacsite_95th_pctl")]
ohio.covariates[, region := "Ohio"]

synth.covariates <- merge(panel[date >= mindate.panel & date <= "2021-05-12", c(
  "popshare_12to17", "popshare_18p",
  "popdensity_2020", "gdp_per_capita_2020", "gop_pct_2020", "influenza_vaccination_pct_2019", "moveidx_retail_recreation",
  "moveidx_grocery_pharmacy", "moveidx_parks", "moveidx_transit", "moveidx_workplaces" ,"moveidx_residential", 
  "miles_vacsite_50th_pctl", "miles_vacsite_95th_pctl", "stname", "date")], 
  synth.weights.dose1[, .(stname, unit_weight_dose1)], all.x = TRUE, by = "stname")
synth.covariates$stname <- NULL
synth.covariates <- synth.covariates[, lapply(.SD, function(x) {sum(x * unit_weight_dose1, na.rm = TRUE)}), by = date]
synth.covariates$date <- NULL
synth.covariates$unit_weight_dose1 <- NULL
synth.covariates <- synth.covariates[, lapply(.SD, mean, na.rm = TRUE)]
synth.covariates[, region := "Synthetic Ohio"]

group.covariates.stats <- rbind(national.covariates, ohio.covariates, synth.covariates)

# Combine the two sets of statistics

group.stats <- merge(group.outcomes.stats, group.covariates.stats)
group.stats[, covid_total_cases_per100kpop_may12 := round(covid_total_cases_per100kpop_may12)]
group.stats[, covid_icu_patdays_per100kpop_may12 := round(covid_icu_patdays_per100kpop_may12)]
group.stats[, gdp_per_capita_2020 := round(gdp_per_capita_2020)]

group.stats[region == "State average", position := 1]
group.stats[region == "Ohio", position := 2]
group.stats[region == "Synthetic Ohio", position := 3]
setkey(group.stats, position)
group.stats$position <- NULL

# Transpose into the three-column table

setnames(group.stats, "region", "")
setnames(group.stats, "popshare_12to17", "Share of population of age 12 to 17 (%)")
setnames(group.stats, "popshare_18p", "Share of population of age 18 or older (%)")
setnames(group.stats, "dose1_per_100pop_april02", "Share of population with any vaccination by April 2, 2021 (%)")
setnames(group.stats, "dose1_per_100pop_may12", "Share of population with any vaccination by May 12, 2021 (%)")
setnames(group.stats, "covid_total_cases_per100kpop_may12", "Total COVID-19 cases per 100k population by May 12, 2021")
setnames(group.stats, "covid_icu_patdays_per100kpop_may12", "Total COVID-19 ICU patient-days per 100k pop. by May 12")
setnames(group.stats, "popdensity_2020", "Population density in 2020 (people per square mile)")
setnames(group.stats, "gdp_per_capita_2020", "Gross domestic product per capita in 2020 ($)")
setnames(group.stats, "gop_pct_2020", "Republican presidential vote share in 2020 (%)")
setnames(group.stats, "influenza_vaccination_pct_2019", "Influenza vaccination rate in 2019 (%)")
setnames(group.stats, "moveidx_retail_recreation", "Community Mobility Report index for retail/recreation")
setnames(group.stats, "moveidx_grocery_pharmacy", "Community Mobility Report index for grocery/pharmacy")
setnames(group.stats, "moveidx_parks", "Community Mobility Report index for parks")
setnames(group.stats, "moveidx_transit", "Community Mobility Report index for transit stations")
setnames(group.stats, "moveidx_workplaces", "Community Mobility Report index for workplaces")
setnames(group.stats, "moveidx_residential", "Community Mobility Report index for residences")
setnames(group.stats, "miles_vacsite_50th_pctl", "Median distance of pop. to closest vaccination site (miles)")
setnames(group.stats, "miles_vacsite_95th_pctl", "95th percentile distance to closest vaccination site (miles)")

group.stats <- t(group.stats)

# Save the table as .tex using Huxtable

sum.states.table <- huxtable(group.stats, add_rownames = TRUE) %>%
  insert_row(after = 1, values = c("Panel [A] Outcome variables in the pre-treatment period", "", "", "")) %>%
  insert_row(after = 6, values = c("Panel [B] Covariates in the pre-treatment period", "", "", "")) %>%
  merge_across(row = c(2,7), col = everywhere) %>%
  set_bold(row = c(2,7), value = TRUE) %>%
  set_align(col = 1, value = "left") %>% set_align(col = 2:4, value = "right") %>%
  set_align(row = 1, col = 2:4, value = "center") %>%
  set_bottom_border(row = 1, col = 2:4) %>%
  set_top_border(row = 1, col = everywhere) %>%
  set_bottom_border(row = c(6,21), col = everywhere) %>%
  set_bottom_padding(row = c(1,6,21), col = everywhere, value = 8)  %>%
  set_top_padding(row = c(2,7), col = everywhere, value = 8)  %>%
  set_number_format(col = 2:4, value = "%.2f")  %>%
  set_number_format(row = c(5, 6, 11),col = 2:4, value = fmt_pretty())
sum.states.table
font_size(sum.states.table) <- 10
sink(file.path(tablesdir, "Summary_Statistics.tex"))
print_latex(sum.states.table, tabular_only = TRUE)
sink()

# Clean up the workspace

rm(group.outcomes.dose1.april02, group.outcomes.dose1.may12, group.outcomes.cases.may12, group.outcomes.icu.may12,
   national.covariates, ohio.covariates, synth.covariates, group.outcomes.stats, group.covariates.stats,
   group.stats, sum.states.table)

#### TABLE: RIDGE AUGMENTED SYNTHETIC CONTROL ESTIMATION RESULTS ####

# Compile a results table

est.results.tab <- rbind(
  
  cbind(
    data.table(Outcome = "Population vaccinated (%)", Date = format(as.Date("2021-05-18"), "%B %d")),
    data.table(summary.est.synth.dose1$att)[Time == "2021-05-18", .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == "2021-05-18"]$dose1_per_100pop)
  ),
  
  cbind(
    data.table(Outcome = "Population vaccinated (%)", Date = format(as.Date("2021-05-25"), "%B %d")),
    data.table(summary.est.synth.dose1$att)[Time == "2021-05-25", .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == "2021-05-25"]$dose1_per_100pop)
  ),
  
  cbind(
    data.table(Outcome = "Population vaccinated (%)", Date = format(as.Date("2021-06-01"), "%B %d")),
    data.table(summary.est.synth.dose1$att)[Time == "2021-06-01", .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == "2021-06-01"]$dose1_per_100pop)
  ),
  
  cbind(
    data.table(Outcome = "Population vaccinated (%)", Date = format(as.Date("2021-06-08"), "%B %d")),
    data.table(summary.est.synth.dose1$att)[Time == "2021-06-08", .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == "2021-06-08"]$dose1_per_100pop)
  ),
  
  cbind(
    data.table(Outcome = "Population vaccinated (%)", Date = format(as.Date("2021-06-15"), "%B %d")),
    data.table(summary.est.synth.dose1$att)[Time == "2021-06-15", .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == "2021-06-15"]$dose1_per_100pop)
  ),
  
  cbind(
    data.table(Outcome = "Population vaccinated (%)", Date = format(as.Date("2021-06-20"), "%B %d")),
    data.table(summary.est.synth.dose1$att)[Time == "2021-06-20", .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == "2021-06-20"]$dose1_per_100pop)
  ),
  
  cbind(
    data.table(Outcome = "Pop. vaccinated 18-older (%)", Date = format(as.Date("2021-06-20"), "%B %d")),
    data.table(summary.est.synth.dose1.18p$att)[Time == "2021-06-20", .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == "2021-06-20"]$dose1_18p_per_100pop)
  ),
  
  cbind(
    data.table(Outcome = "Cases per 100k population", Date = format(as.Date("2021-06-20"), "%B %d")),
    data.table(summary.est.synth.cases$att)[Time == "2021-06-20", .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == "2021-06-20"]$covid_total_cases_per100kpop)
  ),
  
  cbind(
    data.table(Outcome = "Cases per 100k population", Date = format(maxdate.cases, "%B %d")),
    data.table(summary.est.synth.cases$att)[Time == maxdate.cases, .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == maxdate.cases]$covid_total_cases_per100kpop)
  ),
  
  cbind(
    data.table(Outcome = "ICU patient-days per 100k pop.", Date = format(as.Date("2021-06-20"), "%B %d")),
    data.table(summary.est.synth.icu$att)[Time == "2021-06-20", .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == "2021-06-20"]$covid_icu_patdays_per100kpop)
  ),
  
  cbind(
    data.table(Outcome = "ICU patient-days per 100k pop.", Date = format(maxdate.icu, "%B %d")),
    data.table(summary.est.synth.icu$att)[Time == maxdate.icu, .(Estimate, lower_bound, upper_bound)],
    data.table(cf_value = outcomes.panel[region == "Synthetic Ohio" & date == maxdate.icu]$covid_icu_patdays_per100kpop)
  )
)

# Numbers formatting

est.results.tab[, Estimate := formatC(Estimate, digits = 4 , format = "fg", flag = "#")]
est.results.tab[, lower_bound := formatC(lower_bound, digits = 4 , format = "fg", flag = "#")]
est.results.tab[, upper_bound := formatC(upper_bound, digits = 4 , format = "fg", flag = "#")]
est.results.tab[, cf_value := formatC(cf_value, digits = 3 , format = "fg", flag = "#", big.mark = ",")]

# Save the table as .tex using Huxtable

est.results.table <- huxtable(est.results.tab) %>% 
  insert_row(c("Outcome", "Date", "Estimate", "95 pct. conf. interval", "", "Cf. value")) %>%
  set_contents(row = 2, value = c("", "", "", "Low bd.", "Up. bd.", "")) %>% merge_across(row = 1, col = 4:5) %>%
  insert_row(c("Panel [A] COVID-19 vaccinations during the Vax-A-Million treatment period", "", "", "", "", ""), after = 2) %>% 
  merge_across(row = 3, col = 1:6) %>% 
  insert_row(c("Panel [B] COVID-19 infections during the treatment period and post-treatment", "", "", "", "", ""), after = 10) %>% 
  merge_across(row = 11, col = 1:6) %>% 
  set_bold(row = c(3,11), value = TRUE) %>%
  set_align(col = 1:2, value = "left") %>% set_align(col = 3:6, value = "right") %>%
  set_align(row = 1, col = 3, value = "center") %>%
  set_bottom_border(row = 1, col = 4:5) %>%
  set_top_border(row = 1, col = everywhere) %>%
  set_bottom_border(row = 2, col = everywhere) %>%
  set_bottom_border(row = 10, col = everywhere) %>%
  set_bottom_padding(row = 10, col = everywhere, value = 8) %>%
  set_bottom_border(row = 15, col = everywhere) %>%
  set_bottom_padding(row = 15, col = everywhere, value = 8) 
est.results.table
sink(file.path(tablesdir, "Synthetic_Control_Estimation_Results.tex"))
print_latex(est.results.table, tabular_only = TRUE)
sink()

# Clean up the workspace

rm(est.results.tab, est.results.table)

#### TABLE: AGGREGATE IMPACT CALCULATIONS FOR OHIO ####

# Columns for:
#   (1) pre-treatment [April 2 - May 11], to also be a 40-day period
#   (2) first two weeks [May 12 - May 25]
#   (3) full program [May 12 - June 20]
#   (4) two weeks after program [May 12 - July 18]

agg.table <- rbind(
  
  data.table(
    time_period = "April 2 - May 11",
    number_of_days =  as.integer(difftime("2021-05-11", "2021-04-02", units = "days")) + 1,
    ohio_population = panel[stname == "Ohio" & date == "2021-05-11"]$population_2020,
    vam_program_cost = NA,
    compliers_dose1 = NA,
    janssen_dose1 = panel[stname == "Ohio" & date == "2021-05-11"]$dose1_janssen_administered - 
      panel[stname == "Ohio" & date == "2021-04-02"]$dose1_janssen_administered,
    moderna_dose1 = panel[stname == "Ohio" & date == "2021-05-11"]$dose1_moderna_administered - 
      panel[stname == "Ohio" & date == "2021-04-02"]$dose1_moderna_administered,
    pfizer_dose1 = panel[stname == "Ohio" & date == "2021-05-11"]$dose1_pfizer_administered - 
      panel[stname == "Ohio" & date == "2021-04-02"]$dose1_pfizer_administered,
    moderna_dose2_28days = panel[stname == "Ohio" & date == "2021-06-08"]$dose2_moderna_administered - 
      panel[stname == "Ohio" & date == "2021-04-30"]$dose2_moderna_administered,
    pfizer_dose2_21days = panel[stname == "Ohio" & date == "2021-06-01"]$dose2_pfizer_administered - 
      panel[stname == "Ohio" & date == "2021-04-23"]$dose2_pfizer_administered,
    covid_cases_prevented = NA,
    covid_icudays_prevented = NA
  ),
  
  data.table(
    time_period = "May 12 - May 25",
    number_of_days =  as.integer(difftime("2021-05-25", "2021-05-12", units = "days")) + 1,
    ohio_population = panel[stname == "Ohio" & date == "2021-05-11"]$population_2020,
    vam_program_cost = 5600000,
    compliers_dose1 = round(data.table(summary.est.synth.dose1$att)[Time == "2021-05-25"]$Estimate * 
                              panel[stname == "Ohio" & date == "2021-05-11"]$population_2020/100),
    janssen_dose1 = panel[stname == "Ohio" & date == "2021-05-25"]$dose1_janssen_administered - 
      panel[stname == "Ohio" & date == "2021-05-11"]$dose1_janssen_administered,
    moderna_dose1 = panel[stname == "Ohio" & date == "2021-05-25"]$dose1_moderna_administered - 
      panel[stname == "Ohio" & date == "2021-05-11"]$dose1_moderna_administered,
    pfizer_dose1 = panel[stname == "Ohio" & date == "2021-05-25"]$dose1_pfizer_administered - 
      panel[stname == "Ohio" & date == "2021-05-11"]$dose1_pfizer_administered,
    moderna_dose2_28days = panel[stname == "Ohio" & date == "2021-06-22"]$dose2_moderna_administered - 
      panel[stname == "Ohio" & date == "2021-06-08"]$dose2_moderna_administered,
    pfizer_dose2_21days = panel[stname == "Ohio" & date == "2021-06-15"]$dose2_pfizer_administered - 
      panel[stname == "Ohio" & date == "2021-06-01"]$dose2_pfizer_administered,
    covid_cases_prevented = NA,
    covid_icudays_prevented = NA
  ),
  
  data.table(
    time_period = "May 12 - June 20",
    number_of_days =  as.integer(difftime("2021-06-20", "2021-05-12", units = "days")) + 1,
    ohio_population = panel[stname == "Ohio" & date == "2021-05-11"]$population_2020,
    vam_program_cost = 5600000,
    compliers_dose1 = round(data.table(summary.est.synth.dose1$att)[Time == "2021-06-20"]$Estimate * 
                              panel[stname == "Ohio" & date == "2021-05-11"]$population_2020/100),
    janssen_dose1 = panel[stname == "Ohio" & date == "2021-06-20"]$dose1_janssen_administered - 
      panel[stname == "Ohio" & date == "2021-05-11"]$dose1_janssen_administered,
    moderna_dose1 = panel[stname == "Ohio" & date == "2021-06-20"]$dose1_moderna_administered - 
      panel[stname == "Ohio" & date == "2021-05-11"]$dose1_moderna_administered,
    pfizer_dose1 = panel[stname == "Ohio" & date == "2021-06-20"]$dose1_pfizer_administered - 
      panel[stname == "Ohio" & date == "2021-05-11"]$dose1_pfizer_administered,
    moderna_dose2_28days = panel[stname == "Ohio" & date == "2021-07-18"]$dose2_moderna_administered - 
      panel[stname == "Ohio" & date == "2021-06-08"]$dose2_moderna_administered,
    pfizer_dose2_21days = panel[stname == "Ohio" & date == "2021-07-11"]$dose2_pfizer_administered -
    panel[stname == "Ohio" & date == "2021-06-01"]$dose2_pfizer_administered,
    covid_cases_prevented = NA,
    covid_icudays_prevented = NA
  ),
  
  data.table(
    time_period = "May 12 - July 18",
    number_of_days =  as.integer(difftime("2021-07-18", "2021-05-12", units = "days")) + 1,
    ohio_population = panel[stname == "Ohio" & date == "2021-05-11"]$population_2020,
    vam_program_cost = 5600000,
    compliers_dose1 = NA,
    janssen_dose1 = NA,
    moderna_dose1 = NA,
    pfizer_dose1 = NA,
    moderna_dose2_28days = NA,
    pfizer_dose2_21days = NA,
    covid_cases_prevented = -1 * round(panel[stname == "Ohio" & date == "2021-05-11"]$population_2020/100000 *
                                         data.table(summary.est.synth.cases$att)[Time == "2021-07-18"]$Estimate),
    covid_icudays_prevented = -1 * round(panel[stname == "Ohio" & date == "2021-05-11"]$population_2020/100000 *
                                                    data.table(summary.est.synth.icu$att)[Time == "2021-07-18"]$Estimate)
  )
)

agg.table[, total_dose1 := janssen_dose1 + moderna_dose1 + pfizer_dose1]
agg.table[, always_takers_dose1 := total_dose1 - compliers_dose1]
agg.table[time_period == "April 2 - May 11", c("always_takers_dose1", "compliers_dose1") := NA]
agg.table[, cost_per_complier := round(vam_program_cost / compliers_dose1)]
agg.table[, moderna_dose2_follow_up_rate := round(100 * moderna_dose2_28days / moderna_dose1)]
agg.table[, pfizer_dose2_follow_up_rate := round(100 * pfizer_dose2_21days / pfizer_dose1)]
agg.table[, overall_dose2_follow_up_rate := round(100 * (moderna_dose2_28days + pfizer_dose2_21days) / (moderna_dose1 + pfizer_dose1))]
agg.table[, compliers_dose1_pct := round(100 * compliers_dose1 / total_dose1)]
agg.table[, always_takers_dose1_pct := round(100 * always_takers_dose1 / total_dose1)]
agg.table[, janssen_dose1_mktshare := round(100 * janssen_dose1 / total_dose1)]
agg.table[, moderna_dose1_mktshare := round(100 * moderna_dose1 / total_dose1)]
agg.table[, pfizer_dose1_mktshare := round(100 * pfizer_dose1 / total_dose1)]

# Format numbers, add percentages, and rename variables to be table row values

setnames(agg.table, "time_period", "Date range included")
setnames(agg.table, "number_of_days", "Number of days")
agg.table[, `Ohio population` := formatC(ohio_population, big.mark = ",")]
agg.table[, `Vax-A-Million program cost ($)` := ifelse(is.na(vam_program_cost), " ", formatC(vam_program_cost, big.mark = ",", format = "fg"))]
agg.table[, `Total first dose vaccinations` := ifelse(is.na(total_dose1), " ", formatC(total_dose1, big.mark = ",", format = "fg"))]
agg.table[, `First dose compliers` := ifelse(
  is.na(compliers_dose1), " ", paste0(formatC(compliers_dose1, big.mark = ",", format = "fg"), " (", compliers_dose1_pct, "%)"))]
agg.table[, `First dose always-takers` := ifelse(
  is.na(always_takers_dose1), " ", paste0(formatC(always_takers_dose1, big.mark = ",", format = "fg"), " (", always_takers_dose1_pct, "%)"))]
agg.table[, `First dose of Janssen` := ifelse(
  is.na(janssen_dose1), " ", paste0(formatC(janssen_dose1, big.mark = ",", format = "fg"), " (", janssen_dose1_mktshare, "%)"))]
agg.table[, `First dose of Moderna` := ifelse(
  is.na(moderna_dose1), " ", paste0(formatC(moderna_dose1, big.mark = ",", format = "fg"), " (", moderna_dose1_mktshare, "%)"))]
agg.table[, `First dose of Pfizer` := ifelse(
  is.na(pfizer_dose1), " ", paste0(formatC(pfizer_dose1, big.mark = ",", format = "fg"), " (", pfizer_dose1_mktshare, "%)"))]
agg.table[, `Program cost per complier ($)` := ifelse(is.na(cost_per_complier), " ", cost_per_complier)]
agg.table[, `2nd dose Moderna in 28 days` := ifelse(
  is.na(moderna_dose2_28days), " ", formatC(moderna_dose2_28days, big.mark = ",", format = "fg"))]
agg.table[, `2nd dose Pfizer in 21 days` := ifelse(
  is.na(pfizer_dose2_21days), " ", formatC(pfizer_dose2_21days, big.mark = ",", format = "fg"))]
agg.table[, `Moderna follow-up rate` := ifelse(
  is.na(moderna_dose2_follow_up_rate), " ", paste0(moderna_dose2_follow_up_rate, "%"))]
agg.table[, `Pfizer follow-up rate` := ifelse(
  is.na(pfizer_dose2_follow_up_rate), " ", paste0(pfizer_dose2_follow_up_rate, "%"))]
agg.table[, `Overall follow-up rate` := ifelse(
  is.na(overall_dose2_follow_up_rate), " ", paste0(overall_dose2_follow_up_rate, "%"))]
agg.table[, `COVID-19 cases prevented` := ifelse(
  is.na(covid_cases_prevented), " " , formatC(covid_cases_prevented, big.mark = ",", format = "fg"))]
agg.table[, `ICU patient-days prevented` := ifelse(
  is.na(covid_icudays_prevented), " " , formatC(covid_icudays_prevented, big.mark = ",", format = "fg"))]

# Transpose into the four-column table

pretty.agg.table <- t(agg.table[, .(`Date range included`, `Number of days`, `Ohio population`, `Vax-A-Million program cost ($)`, 
                                    `Total first dose vaccinations`, `First dose compliers`, `First dose always-takers`, 
                                    `First dose of Janssen`, `First dose of Moderna`, `First dose of Pfizer`,
                                    `Program cost per complier ($)`, `2nd dose Moderna in 28 days`, `Moderna follow-up rate`,
                                    `2nd dose Pfizer in 21 days`, `Pfizer follow-up rate`,
                                    `Overall follow-up rate`, `COVID-19 cases prevented`, `ICU patient-days prevented`)])

# Save the table as .tex using Huxtable

agg.results.table <- huxtable(pretty.agg.table, add_rownames = TRUE) %>%
  insert_row(after = 0, c(" ", "Pre-treatment", "First two weeks", "Full period", "Post-treatment")) %>%
  insert_row(after = 0, c(" ", "", "Vax-A-Million treatment period", "", "")) %>%
  merge_across(row = 1, col = 3:5) %>%
  set_align(col = 1, value = "left") %>% set_align(col = 2:5, value = "right") %>%
  set_align(row = 1:2, col = 2:5, value = "center") %>%
  set_bottom_border(row = 1, col = 3:5) %>%
  set_bottom_border(row = 2, col = 2:5) %>%
  set_top_border(row = 1, col = everywhere) %>%
  set_bottom_border(row = 20, col = everywhere) %>%
  set_bottom_padding(row = c(1,20), col = everywhere, value = 8) %>%
  set_bottom_border(row = 20, col = everywhere) %>%
  set_left_padding(row = c(8:12, 15, 17), col = 1, value = 20)
font_size(agg.results.table) <- 10
agg.results.table
sink(file.path(tablesdir, "Ohio_Aggregate_Results.tex"))
print_latex(agg.results.table, tabular_only = TRUE)
sink()

rm(agg.table, pretty.agg.table, agg.results.table)

#### END ####
