# Updated 2021 December 15

#### CODE PREAMBLE AND DESCRIPTION ####

## Code preamble: prepare workspace and load R packages

rm(list = ls())     # Clear workspace
library(ggplot2)    # R package for plotting graphs
library(data.table) # R package for using data.tables as augmented data.frames
datadir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/data" # SET THIS: top-level data directory
figuresdir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/figures" # SET THIS: directory in which to save figures
setwd(datadir)

## Generates three (sub-)figures:
#
#  - Janssen's daily market share of first dose vaccinations in Ohio and National
#  - Moderna's daily market share of first dose vaccinations in Ohio and National
#  - Pfizer's  daily market share of first dose vaccinations in Ohio and National
#

## Data and programming notes:
#
# 1. Running this code requires fairly little computer RAM, less than 1 GB. 
#
# 2. Although the first dose vaccinations data start on February 19, 2021, Janssen data starts March 5, 2021
#

#### LOAD AND PREPARE DATA ####

panel <- fread("analysis_panel.csv")[date <= "2021-07-14"]
setkey(panel, fips, date)

dose1 <- panel[date >= "2021-03-05",
               .(stname, date, dose1_janssen_administered, dose1_moderna_administered, dose1_pfizer_administered)]

dose1[, daily_janssen_dose1 := dose1_janssen_administered - shift(dose1_janssen_administered)]
dose1[, daily_moderna_dose1 := dose1_moderna_administered - shift(dose1_moderna_administered)]
dose1[, daily_pfizer_dose1 := dose1_pfizer_administered - shift(dose1_pfizer_administered)]
dose1[stname != shift(stname), c("daily_janssen_dose1", "daily_moderna_dose1", "daily_pfizer_dose1") := NA]

# Correct for data inaccuracies in the computed daily values by replacing negative vaccine volumes

dose1[daily_janssen_dose1 <= 0, daily_janssen_dose1 := 1]
dose1[daily_moderna_dose1 <= 0, daily_moderna_dose1 := 1]
dose1[daily_pfizer_dose1 <= 0, daily_pfizer_dose1 := 1]

# Compute the market share by date for each manufacturer for Ohio

ohio <- dose1[date > "2021-03-05" & stname == "Ohio", 
              .(region = "Ohio", date, daily_janssen_dose1, daily_moderna_dose1, daily_pfizer_dose1)]

ohio[, daily_janssen_dose1_mktshare := 100 * daily_janssen_dose1 / (daily_janssen_dose1 + daily_moderna_dose1 + daily_pfizer_dose1)]
ohio[, daily_moderna_dose1_mktshare := 100 * daily_moderna_dose1 / (daily_janssen_dose1 + daily_moderna_dose1 + daily_pfizer_dose1)]
ohio[, daily_pfizer_dose1_mktshare := 100 * daily_pfizer_dose1 / (daily_janssen_dose1 + daily_moderna_dose1 + daily_pfizer_dose1)]

# Compute the market share by date for each manufacturer Nationally

national <- dose1[date > "2021-03-05", lapply(.SD, sum), by = date, 
                  .SDcols = c("daily_janssen_dose1", "daily_moderna_dose1", "daily_pfizer_dose1")]

national[, region := "National"]

national[, daily_janssen_dose1_mktshare := 100 * daily_janssen_dose1 / (daily_janssen_dose1 + daily_moderna_dose1 + daily_pfizer_dose1)]
national[, daily_moderna_dose1_mktshare := 100 * daily_moderna_dose1 / (daily_janssen_dose1 + daily_moderna_dose1 + daily_pfizer_dose1)]
national[, daily_pfizer_dose1_mktshare := 100 * daily_pfizer_dose1 / (daily_janssen_dose1 + daily_moderna_dose1 + daily_pfizer_dose1)]

# Form the graph data

gg.mktshare <- rbind(
  ohio[, .(region, date, daily_janssen_dose1_mktshare, daily_moderna_dose1_mktshare, daily_pfizer_dose1_mktshare)],
  national[, .(region, date, daily_janssen_dose1_mktshare, daily_moderna_dose1_mktshare, daily_pfizer_dose1_mktshare)]
)

#### FIGURES: PLOT AND SAVE THE DAILY MARKET SHARE GRAPHS ####

# Janssen's daily market share of first dose vaccinations in Ohio and National

ggplot(gg.mktshare, aes(x = date, y = daily_janssen_dose1_mktshare, group = region, color = region, linetype = region)) +
  geom_line() +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  annotate("label", x = as.Date("2021-05-31"), y = 88, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12th\nand ended on June 20th", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "Daily market share of first dose vaccinations (%)", breaks = c(0, 25, 50, 75, 100), limits = c(0, 100)) +
  scale_linetype_manual(name = "Region", values = c("longdash", "solid")) +
  scale_color_manual(name = "Region", values = c("grey60", "#BB0000", "black")) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.12, 0.83))

ggsave(file.path(figuresdir, "Daily_Market_Share_Dose1_Ohio_National_Janssen.pdf"), width = 8, height = 4, units = "in", dpi = 300)

# Moderna's daily market share of first dose vaccinations in Ohio and National

ggplot(gg.mktshare, aes(x = date, y = daily_moderna_dose1_mktshare, group = region, color = region, linetype = region)) +
  geom_line() +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  annotate("label", x = as.Date("2021-05-31"), y = 88, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12th\nand ended on June 20th", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "Daily market share of first dose vaccinations (%)", breaks = c(0, 25, 50, 75, 100), limits = c(0, 100)) +
  scale_linetype_manual(name = "Region", values = c("longdash", "solid")) +
  scale_color_manual(name = "Region", values = c("grey60", "#BB0000", "black")) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.12, 0.83))

ggsave(file.path(figuresdir, "Daily_Market_Share_Dose1_Ohio_National_Moderna.pdf"), width = 8, height = 4, units = "in", dpi = 300)

# Pfizer's daily market share of first dose vaccinations in Ohio and National

ggplot(gg.mktshare, aes(x = date, y = daily_pfizer_dose1_mktshare, group = region, color = region, linetype = region)) +
  geom_line() +
  geom_vline(xintercept = as.Date("2021-05-12"), color = "#BB0000", linetype = "dashed") +
  geom_vline(xintercept = as.Date("2021-06-20"), color = "#BB0000", linetype = "dashed") +
  annotate("label", x = as.Date("2021-05-31"), y = 88, 
           label = "Ohio's Vax-A-Million was\nannounced on May 12th\nand ended on June 20th", color = "#BB0000", size = 3) +
  scale_x_date(name = "Date in 2021", date_breaks = "1 months", date_labels = "%B") +
  scale_y_continuous(name = "Daily market share of first dose vaccinations (%)", breaks = c(0, 25, 50, 75, 100), limits = c(0, 100)) +
  scale_linetype_manual(name = "Region", values = c("longdash", "solid")) +
  scale_color_manual(name = "Region", values = c("grey60", "#BB0000", "black")) +
  theme_bw() + theme(panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(),
                     legend.background = element_rect(color = "black", fill = "white"), legend.position = c(0.12, 0.83))

ggsave(file.path(figuresdir, "Daily_Market_Share_Dose1_Ohio_National_Pfizer.pdf"), width = 8, height = 4, units = "in", dpi = 300)

#### END ####
